from moodle.base.general import GeneralValidated


class ValidatedKey(GeneralValidated):
    """ValidatedKey
    Args:
        validated (int): Whether the key is validated or not.
        warnings (List[Warning]): list of warnings
    """
    pass
