from moodle.base.general import GeneralTypeValue


class UserPreference(GeneralTypeValue):
    """User preferences

    Args:
        type (str): The name of the preference
        value (str): The value of the preference
    """
    pass
